# 目录结构

```
├── 01_股票数据/
│   ├── 01_基础数据/
│   │   ├── 01_股票列表.md (获取基础信息数据，包括股票代码、名称、上市日期、退市日期等，需要2000积分)
│   │   ├── 02_每日股本（盘前）.md (每日开盘前获取当日股票的股本情况，包括总股本和流通股本，涨跌停价格等，需要单独权限)
│   │   ├── 03_交易日历.md (获取各大交易所交易日历数据,默认提取的是上交所，需要2000积分)
│   │   ├── 04_ST股票列表.md (获取ST股票列表，可根据交易日期获取历史上每天的ST列表，需要3000积分)
│   │   ├── 05_沪深港通股票列表.md (获取沪深港通股票列表，需要3000积分)
│   │   ├── 06_股票曾用名.md (历史名称变更记录)
│   │   ├── 07_上市公司基本信息.md (获取上市公司基础信息，需要120积分)
│   │   ├── 08_上市公司管理层.md (获取上市公司管理层，需要2000积分)
│   │   ├── 09_管理层薪酬和持股.md (获取上市公司管理层薪酬和持股，需要2000积分)
│   │   ├── 10_北交所新旧代码对照.md (获取北交所股票代码变更后新旧代码映射表数据，需要120积分)
│   │   ├── 11_IPO新股上市.md (获取新股上市列表数据，需要120积分)
│   │   └── 12_股票历史列表.md (获取备用基础列表，数据从2016年开始，需要5000积分)
│   ├── 02_行情数据/
│   │   ├── 01_历史日线.md (获取股票行情数据，包含了前后复权数据)
│   │   ├── 02_实时K线.md (获取实时日k线行情，支持按股票代码及股票代码通配符一次性提取全部股票实时日k线行情，需要单独权限)
│   │   ├── 03_历史分钟.md (获取A股分钟数据，支持1min/5min/15min/30min/60min行情，需要单独权限)
│   │   ├── 04_实时分钟.md (获取全A股票实时分钟数据，包括1~60min，需要单独权限)
│   │   ├── 05_周线行情.md (获取A股周线行情，需要2000积分)
│   │   ├── 06_月线行情.md (获取A股月线数据，需要2000积分)
│   │   ├── 07_复权行情.md (获取A股复权行情，通过通用行情接口实现)
│   │   ├── 08_周_月线行情_每日更新.md (股票周/月线行情(每日更新))
│   │   ├── 09_周_月线复权行情_每日更新.md (股票周/月线行情(复权--每日更新)，需要2000积分)
│   │   ├── 10_复权因子.md (获取股票复权因子，可提取单只股票全部历史复权因子或单日全部股票的复权因子，需要2000积分)
│   │   ├── 11_实时Tick（爬虫）.md (A股实时行情)
│   │   ├── 12_实时成交（爬虫）.md (实时成交数据)
│   │   ├── 13_实时排名（爬虫）.md (实时涨跌幅排名)
│   │   ├── 14_每日指标.md (获取全部股票每日重要的基本面指标，需要2000积分)
│   │   ├── 15_通用行情接口.md (集成开发接口，整合了股票、指数、数字货币、ETF基金、期货、期权的行情数据)
│   │   ├── 16_每日涨跌停价格.md (获取全市场每日涨跌停价格，包括涨停价格，跌停价格等，需要2000积分)
│   │   ├── 17_每日停复牌信息.md (按日期方式获取股票每日停复牌信息)
│   │   ├── 18_沪深股通十大成交股.md (获取沪股通、深股通每日前十大成交详细数据)
│   │   ├── 19_港股通十大成交股.md (获取港股通每日成交数据，其中包括沪市、深市详细数据)
│   │   ├── 20_港股通每日成交统计.md (获取港股通每日成交信息，数据从2014年开始，需要2000积分)
│   │   ├── 21_港股通每月成交统计.md (港股通每月成交信息，数据从2014年开始，需要5000积分)
│   │   └── 22_备用行情.md (获取备用行情，包括特定的行情指标，需要5000积分)
│   ├── 03_财务数据/
│   │   ├── 01_利润表.md (获取上市公司财务利润表数据，需要2000积分)
│   │   ├── 02_资产负债表.md (获取上市公司资产负债表，需要2000积分)
│   │   ├── 03_现金流量表.md (获取上市公司现金流量表，需要2000积分)
│   │   ├── 04_业绩预告.md (获取业绩预告数据，需要2000积分)
│   │   ├── 05_业绩快报.md (获取上市公司业绩快报，需要2000积分)
│   │   ├── 06_分红送股数据.md (分红送股数据，需要2000积分)
│   │   ├── 07_财务指标数据.md (获取上市公司财务指标数据，需要2000积分)
│   │   ├── 08_财务审计意见.md (获取上市公司定期财务审计意见数据，需要500积分)
│   │   ├── 09_主营业务构成.md (获得上市公司主营业务构成，分地区和产品两种方式，需要2000积分)
│   │   └── 10_财报披露日期表.md (获取财报披露计划日期，需要500积分)
│   ├── 04_参考数据/
│   │   ├── 01_前十大股东.md (获取上市公司前十大股东数据，包括持有数量和比例等信息，需要2000积分)
│   │   ├── 02_前十大流通股东.md (获取上市公司前十大流通股东数据，需要2000积分)
│   │   ├── 03_股权质押统计数据.md (获取股票质押统计数据，需要500积分)
│   │   ├── 04_股权质押明细数据.md (获取股票质押明细数据，需要500积分)
│   │   ├── 05_股票回购.md (获取上市公司回购股票数据，需要600积分)
│   │   ├── 06_限售股解禁.md (获取限售股解禁数据，需要120积分)
│   │   ├── 07_大宗交易.md (获取大宗交易数据，需要300积分)
│   │   ├── 08_股票开户数据（停）.md (获取股票账户开户数据，需要600积分)
│   │   ├── 09_股票开户数据（旧）.md (获取股票账户开户数据旧版格式数据，需要600积分)
│   │   ├── 10_股东人数.md (获取上市公司股东户数数据，需要600积分)
│   │   └── 11_股东增减持.md (获取上市公司增减持数据，了解重要股东近期及历史上的股份增减变化，需要2000积分)
│   ├── 05_特色数据/
│   │   ├── 01_券商盈利预测数据.md (获取券商（卖方）每天研报的盈利预测数据，需要120积分)
│   │   ├── 02_每日筹码及胜率.md (获取A股每日筹码平均成本和胜率情况，需要120积分)
│   │   ├── 03_每日筹码分布.md (获取A股每日的筹码分布情况，提供各价位占比，需要120积分)
│   │   ├── 04_股票技术面因子.md (获取股票每日技术面因子数据，用于跟踪股票当前走势情况，需要5000积分)
│   │   ├── 05_股票技术面因子_专业版）.md (获取股票每日技术面因子数据，用于跟踪股票当前走势情况，需要5000积分)
│   │   ├── 06_中央结算系统持股统计.md (获取中央结算系统持股汇总数据，需要120积分)
│   │   ├── 07_中央结算系统持股明细.md (获取中央结算系统机构席位持股明细，需要8000积分)
│   │   ├── 08_沪深股通持股明细.md (获取沪深港股通持股明细，需要120积分)
│   │   ├── 09_股票开盘集合竞价数据.md (获取股票开盘9:30集合竞价数据，需要单独权限)
│   │   ├── 10_股票收盘集合竞价数据.md (获取股票收盘15:00集合竞价数据，需要单独权限)
│   │   ├── 11_神奇九转指标.md (获取神奇九转（又称"九转序列"）指标数据，用于判断股价的潜在反转点，需要6000积分)
│   │   ├── 12_AH股比价.md (获取AH股比价数据，需要5000积分)
│   │   ├── 13_机构调研数据.md (获取上市公司机构调研记录数据，需要5000积分)
│   │   └── 14_券商月度金股.md (获取券商月度金股，需要2000积分)
│   ├── 06_两融及转融通/
│   │   ├── 01_融资融券交易汇总.md (获取融资融券每日交易汇总数据，需要2000积分)
│   │   ├── 02_融资融券交易明细.md (获取沪深两市每日融资融券明细，需要2000积分)
│   │   ├── 03_融资融券标的（盘前）.md (获取沪深京三大交易所融资融券标的（包括ETF），需要2000积分)
│   │   ├── 04_转融券交易汇总_停）.md (获取转融通转融券交易汇总，需要2000积分)
│   │   ├── 05_转融资交易汇总.md (获取转融通融资汇总，需要2000积分)
│   │   ├── 06_转融券交易明细_停）.md (获取转融券交易明细，需要2000积分)
│   │   └── 07_做市借券交易汇总_停）.md (获取做市借券交易汇总，需要2000积分)
│   ├── 07_资金流向数据/
│   │   ├── 01_个股资金流向.md (获取沪深A股票资金流向数据，分析大单小单成交情况，用于判别资金动向，需要2000积分)
│   │   ├── 02_个股资金流向（THS）.md (获取同花顺个股资金流向数据，需要5000积分)
│   │   ├── 03_个股资金流向（DC）.md (获取东方财富个股资金流向数据，需要5000积分)
│   │   ├── 04_板块资金流向（THS.md (获取同花顺概念板块每日资金流向，需要5000积分)
│   │   ├── 05_行业资金流向（THS）.md (获取同花顺行业资金流向，需要5000积分)
│   │   ├── 06_板块资金流向（DC）.md (获取东方财富板块资金流向，需要5000积分)
│   │   ├── 07_大盘资金流向（DC）.md (获取东方财富大盘资金流向数据，需要120积分)
│   │   └── 08_沪深港通资金流向.md (获取沪股通、深股通、港股通每日资金流向数据，需要2000积分)
│   ├── 08_打板专题数据/
│   │   ├── 01_题材数据（开盘啦）.md (获取开盘啦概念题材列表，需要5000积分)
│   │   ├── 02_题材成分（开盘啦）.md (获取开盘啦概念题材的成分股，需要5000积分)
│   │   ├── 03_榜单数据（开盘啦）.md (获取开盘啦涨停、跌停、炸板等榜单数据，需要5000积分)
│   │   ├── 04_龙虎榜每日统计单.md (获取龙虎榜每日交易明细，需要2000积分)
│   │   ├── 05_龙虎榜机构交易单.md (获取龙虎榜机构成交明细，需要2000积分)
│   │   ├── 06_同花顺涨跌停榜单.md (获取同花顺每日涨跌停榜单数据，需要8000积分)
│   │   ├── 07_涨跌停和炸板数据.md (获取A股每日涨跌停、炸板数据情况，需要5000积分)
│   │   ├── 08_涨停股票连板天梯.md (获取每天连板个数晋级的股票，需要8000积分)
│   │   ├── 09_涨停最强板块统计.md (获取每天涨停股票最多最强的概念板块，需要8000积分)
│   │   ├── 10_同花顺行业概念板块.md (获取同花顺板块指数，需要6000积分)
│   │   ├── 11_同花顺概念和行业指数行情.md (获取同花顺板块指数行情，需要6000积分)
│   │   ├── 12_同花顺行业概念成分.md (获取同花顺概念板块成分列表，需要5000积分)
│   │   ├── 13_东方财富概念板块.md (获取东方财富每个交易日的概念板块数据，需要6000积分)
│   │   ├── 14_东方财富概念成分.md (获取东方财富板块每日成分数据，需要6000积分)
│   │   ├── 15_东财概念和行业指数行情.md (获取东财概念板块、行业指数板块、地域板块行情数据，需要6000积分)
│   │   ├── 16_开盘竞价成交（当日）.md (获取当日个股和ETF的集合竞价成交情况，需要单独权限)
│   │   ├── 17_市场游资最全名录.md (获取游资分类名录信息，需要5000积分)
│   │   ├── 18_游资交易每日明细.md (获取每日游资交易明细，需要10000积分)
│   │   ├── 19_同花顺App热榜数.md (获取同花顺App热榜数据，包括热股、概念板块、ETF、可转债、港美股等等，需要5000积分)
│   │   ├── 20_东方财富App热榜.md (获取东方财富App热榜数据，包括A股市场、ETF基金、港股市场、美股市场等等，需要8000积分)
│   │   ├── 21_通达信板块信息.md (获取通达信板块基础信息，包括概念板块、行业、风格、地域等，需要6000积分)
│   │   ├── 22_通达信板块成分.md (获取通达信各板块成分股信息，需要6000积分)
│   │   └── 23_通达信板块行情.md (获取通达信各板块行情，包括成交和估值等数据，需要6000积分)
│   └── README.md
├── 02_ETF专题/
│   ├── 01_ETF基本信息.md (获取国内ETF基础信息，包括了QDII，需要8000积分)
│   ├── 02_ETF基准指数.md (获取ETF基准指数列表信息，需要8000积分)
│   ├── 03_ETF分钟行情.md (获取ETF分钟数据，支持1min/5min/15min/30min/60min行情，需要单独权限)
│   ├── 04_ETF日线行情.md (获取ETF行情每日收盘后成交数据，需要2000积分)
│   └── 05_ETF复权因子.md (获取基金复权因子，用于计算基金复权行情，需要600积分)
├── 03_指数专题/
│   ├── 01_指数基本信息.md (获取指数基础信息)
│   ├── 02_指数日线行情.md (获取指数每日行情，需要2000积分)
│   ├── 03_指数周线行情.md (获取指数周线行情，需要600积分)
│   ├── 04_指数月线行情.md (获取指数月线行情，需要600积分)
│   ├── 05_指数成分和权重.md (获取各类指数成分和权重，需要2000积分)
│   ├── 06_大盘指数每日指标.md (获取大盘指数每日指标数据，需要400积分)
│   ├── 07_申万行业分类.md (获取申万行业分类，需要2000积分)
│   ├── 08_申万行业成分（分级）.md (按三级分类提取申万行业成分，需要2000积分)
│   ├── 09_申万行业指数日行情.md (获取申万行业日线行情，默认是申万2021版行情，需要5000积分)
│   ├── 10_中信行业成分.md (按三级分类提取中信行业成分，需要5000积分)
│   ├── 11_中信行业指数日行情.md (获取中信行业指数日线行情，需要5000积分)
│   ├── 12_国际主要指数.md (获取国际主要指数日线行情，需要6000积分)
│   ├── 13_指数技术面因子_专业版.md (获取指数每日技术面因子数据，用于跟踪指数当前走势情况，需要5000积分)
│   ├── 14_沪深市场每日交易统计.md (获取交易所股票交易统计，包括各板块明细，需要600积分)
│   └── 15_深圳市场每日交易情况.md (获取深圳市场每日交易概况，需要2000积分)
├── 04_公募基金/
│   ├── 01_基金列表.md (获取公募基金数据列表，包括场内和场外基金，需要2000积分)
│   ├── 02_基金管理人.md (获取公募基金管理人列表，需要1500积分)
│   ├── 03_基金经理.md (获取公募基金经理数据，包括基金经理简历等数据，需要500积分)
│   ├── 04_基金规模.md (获取基金规模数据，包含上海和深圳ETF基金，需要2000积分)
│   ├── 05_基金净值.md (获取公募基金净值数据，需要2000积分)
│   ├── 06_基金分红.md (获取公募基金分红数据，需要400积分)
│   ├── 07_基金持仓.md (获取公募基金持仓数据，季度更新，需要5000积分)
│   └── 08_基金技术面因子_专业版.md (获取场内基金每日技术面因子数据，用于跟踪场内基金当前走势情况，需要5000积分)
├── 05_期货数据/
│   ├── 01_合约信息.md (获取期货合约列表数据，需要2000积分)
│   ├── 02_交易日历.md (获取各大期货交易所交易日历数据，需要2000积分)
│   ├── 03_日线行情.md (获取期货日线行情数据，需要2000积分)
│   ├── 04_期货周_月线行情_每日更新.md (获取期货周/月线行情)
│   ├── 05_历史分钟行情.md (获取全市场期货合约分钟数据，支持1min/5min/15min/30min/60min行情，需要120积分)
│   ├── 06_实时分钟行情.md (获取全市场期货合约实时分钟数据，支持1min/5min/15min/30min/60min行情，需要单独权限)
│   ├── 07_仓单日报.md (获取仓单日报数据，了解各仓库/厂库的仓单变化，需要2000积分)
│   ├── 08_每日结算参数.md (获取每日结算参数数据，包括交易和交割费率等，需要2000积分)
│   ├── 09_历史Tick行情.md (获取全市场期货合约的Tick高频行情，当前不提供API方式获取，只提供csv网盘交付)
│   ├── 10_每日持仓排名.md (获取每日成交持仓排名数据，需要2000积分)
│   ├── 11_南华期货指数行情.md (获取南华指数每日行情，需要2000积分)
│   ├── 12_期货主力与连续合约.md (获取期货主力（或连续）合约与月合约映射数据，需要2000积分)
│   ├── 13_期货主要品种交易周报.md (获取期货交易所主要品种每周交易统计信息，需要600积分)
│   └── 14_期货合约涨跌停价格.md (获取所有期货合约每天的涨跌停价格及最低保证金率，需要5000积分)
├── 06_现货数据/
│   ├── 01_上海黄金基础信息.md (获取上海黄金交易所现货合约基础信息，需要5000积分)
│   └── 02_上海黄金现货日行情.md (获取上海黄金交易所现货合约日线行情，需要2000积分)
├── 07_期权数据/
│   ├── 01_期权合约信息.md (获取期权合约信息，需要5000积分)
│   ├── 02_期权日线行情.md (获取期权日线行情，需要2000积分)
│   └── 03_期权分钟行情.md (获取全市场期权合约分钟数据，支持1min/5min/15min/30min/60min行情，需要120积分)
├── 08_债券专题/
│   ├── 01_可转债基础信息.md (获取可转债基本信息，需要2000积分)
│   ├── 02_可转债发行.md (获取可转债发行数据，需要2000积分)
│   ├── 03_可转债赎回信息.md (获取可转债到期赎回、强制赎回等信息，需要5000积分)
│   ├── 04_可转债票面利率.md (获取可转债票面利率，需要5000积分)
│   ├── 05_可转债行情.md (获取可转债行情，需要2000积分)
│   ├── 06_可转债技术面因子_专业版）.md (获取可转债每日技术面因子数据，用于跟踪可转债当前走势情况，需要5000积分)
│   ├── 07_可转债转股价变动.md (获取可转债转股价变动，需要单独权限)
│   ├── 08_可转债转股结果.md (获取可转债转股结果，需要2000积分)
│   ├── 09_债券回购日行情.md (获取债券回购日行情，需要2000积分)
│   ├── 10_柜台流通式债券报价.md (获取柜台流通式债券报价，需要500积分)
│   ├── 11_柜台流通式债券最优报价.md (获取柜台流通式债券最优报价，需要500积分)
│   ├── 12_大宗交易.md (获取沪深交易所债券大宗交易数据，需要5000积分)
│   ├── 13_大宗交易明细.md (获取沪深交易所债券大宗交易数据，需要5000积分)
│   ├── 14_国债收益率曲线.md (获取中债收益率曲线，需要单独权限)
│   └── 15_全球财经事件.md (获取全球财经日历、包括经济事件数据更新，需要2000积分)
├── 09_外汇数据/
│   ├── 01_外汇基础信息（海外）.md (获取海外外汇基础信息，目前只有FXCM交易商的数据，需要2000积分)
│   └── 02_外汇日线行情.md (获取外汇日线行情，需要2000积分)
├── 10_港股数据/
│   ├── 01_港股基础信息.md (获取港股列表信息，需要2000积分)
│   ├── 02_港股交易日历.md (获取交易日历，需要2000积分)
│   ├── 03_港股日线行情.md (获取港股每日增量和历史行情，需要单独权限)
│   ├── 04_港股复权行情.md (获取港股复权行情，提供股票股本、市值和成交及换手多个数据指标，需要120积分)
│   ├── 05_港股分钟行情.md (获取港股分钟数据，支持1min/5min/15min/30min/60min行情，需要120积分)
│   ├── 06_港股实时日线.md (获取港股实时日k线行情，支持按股票代码及股票代码通配符一次性提取全部股票实时日k线行情，需要单独权限)
│   ├── 07_港股利润表.md (获取港股上市公司财务利润表数据，需要单独权限或15000积分)
│   ├── 08_港股资产负债表.md (获取港股上市公司资产负债表，需要单独权限或15000积分)
│   ├── 09_港股现金流量表.md (获取港股上市公司现金流量表数据，需要单独权限或15000积分)
│   └── 10_港股财务指标数据.md (获取港股上市公司财务指标数据，需要单独权限或15000积分)
├── 11_美股数据/
│   ├── 01_美股基础信息.md (获取美股列表信息，需要120积分)
│   ├── 02_美股交易日历.md (获取美股交易日历信息)
│   ├── 03_美股日线行情.md (获取美股行情（未复权），包括全部股票全历史行情，以及重要的市场和估值指标，需要120积分)
│   ├── 04_美股复权行情.md (获取美股复权行情，支持美股全市场股票，提供股本、市值、复权因子和成交信息等多个数据指标，需要120积分)
│   ├── 05_美股利润表.md (获取美股上市公司财务利润表数据（目前只覆盖主要美股和中概股），需要单独权限或15000积分)
│   ├── 06_美股资产负债表.md (获取美股上市公司资产负债表（目前只覆盖主要美股和中概股），需要单独权限或15000积分)
│   ├── 07_美股现金流量表.md (获取美股上市公司现金流量表数据（目前只覆盖主要美股和中概股），需要单独权限或15000积分)
│   └── 08_美股财务指标数据.md (获取美股上市公司财务指标数据，目前只覆盖主要美股和中概股，需要单独权限或15000积分)
├── 12_行业经济/
│   └── 01_TMT行业/
│       ├── 01_台湾电子产业月营收.md (获取台湾TMT电子产业领域各类产品月度营收数据)
│       ├── 02_台湾电子产业月营收明细.md (获取台湾TMT行业上市公司各类产品月度营收情况)
│       ├── 03_电影月度票房.md (获取电影月度票房数据，需要500积分)
│       ├── 04_电影周度票房.md (获取周度票房数据，需要500积分)
│       ├── 05_电影日度票房.md (获取电影日度票房，需要500积分)
│       ├── 06_影院日度票房.md (获取每日各影院的票房数据，需要500积分)
│       ├── 07_全国电影剧本备案数据.md (获取全国电影剧本备案的公示数据，需要120积分)
│       └── 08_全国电视剧备案公示数据.md (获取2009年以来全国拍摄制作电视剧备案公示数据，需要600积分)
├── 13_宏观经济/
│   └── 01_国内宏观/
│       ├── 01_利率数据/
│       │   ├── 01_Shibor利率.md (获取shibor利率数据，需要120积分)
│       │   ├── 02_Shibor报价数据.md (获取Shibor报价数据，需要120积分)
│       │   ├── 03_LPR贷款基础利率.md (获取LPR贷款基础利率，需要120积分)
│       │   ├── 04_Libor利率.md (获取Libor拆借利率，需要120积分)
│       │   ├── 05_Hibor利率.md (获取Hibor利率，需要120积分)
│       │   ├── 06_温州民间借贷利率.md (获取温州民间借贷利率，即温州指数，需要2000积分)
│       │   └── 07_广州民间借贷利率.md (获取广州民间借贷利率，需要2000积分)
│       ├── 02_国民经济/
│       │   └── 01_国内生产总值（GDP）.md (获取国民经济之GDP数据，需要600积分)
│       ├── 03_价格指数/
│       │   ├── 01_居民消费价格指数（CPI）.md (获取CPI居民消费价格数据，包括全国、城市和农村的数据，需要600积分)
│       │   └── 02_工业生产者出厂价格指数（PPI）.md (获取PPI工业生产者出厂价格指数数据，需要600积分)
│       ├── 04_金融/
│       │   ├── 01_货币供应量/
│       │   │   └── 01_货币供应量（月）.md (获取货币供应量之月度数据，需要600积分)
│       │   └── 02_社会融资/
│       │       └── 01_社融增量（月度）.md (获取月度社会融资数据，需要2000积分)
│       └── 05_景气度/
│           └── 01_采购经理指数（PMI）.md (获取采购经理人指数，需要2000积分)
└── 14_大模型语料专题数据/
    ├── 01_新闻快讯（短讯）.md (获取主流新闻网站的快讯新闻数据,提供超过6年以上历史新闻，需要单独权限)
    ├── 02_新闻通讯（长篇）.md (获取长篇通讯信息，覆盖主要新闻资讯网站，提供超过8年历史新闻，需要单独权限)
    ├── 03_新闻联播文字稿.md (获取新闻联播文字稿数据，数据开始于2006年6月，超过12年历史，需要单独权限)
    ├── 04_上市公司公告.md (获取全量公告数据，提供pdf下载URL，需要单独权限)
    ├── 05_上证e互动问答.md (获取上交所e互动董秘问答文本数据，需要120积分)
    └── 06_深证易互动问答.md (获取深交所互动易董秘问答文本数据，需要120积分)
└── 15_财富管理/
    └── 01_基金销售行业数据/
        ├── 01_各渠道公募基金销售保有规模占比.md (获取各渠道公募基金销售保有规模占比数据，年度更新)
        └── 02_销售机构公募基金销售保有规模.md (获取销售机构公募基金销售保有规模数据，本数据从2021年Q1开始公布，季度更新)
```